package com.mapbar.android.maps.demo;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import android.app.Activity;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ListView;
import android.widget.SimpleAdapter;

/**
 * @Module com.mapbar.android.maps.demo.MapbarDemo
 * @description Mapbar 地图操作定位Demo 入口
 * @author
 * @version 1.0
 * @created Dec 13, 2011
 */
public class MapbarDemo extends Activity {
	private ListView listView;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {

		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		listView = (ListView) findViewById(R.id.lv);
		List<Map<String, Object>> adapt = new ArrayList<Map<String, Object>>();
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("map_show_item", getString(R.string.map));
		adapt.add(map);

		map = new HashMap<String, Object>();
		map.put("map_show_item", getString(R.string.move_map));
		adapt.add(map);

		map = new HashMap<String, Object>();
		map.put("map_show_item", getString(R.string.zoom_map));
		adapt.add(map);

		map = new HashMap<String, Object>();
		map.put("map_show_item", getString(R.string.label_map));
		adapt.add(map);

		map = new HashMap<String, Object>();
		map.put("map_show_item", getString(R.string.line_map));
		adapt.add(map);

		map = new HashMap<String, Object>();
		map.put("map_show_item", getString(R.string.polygon_map));
		adapt.add(map);

		map = new HashMap<String, Object>();
		map.put("map_show_item", getString(R.string.circle_map));
		adapt.add(map);

		map = new HashMap<String, Object>();
		map.put("map_show_item", getString(R.string.intent_way));
		adapt.add(map);

		map = new HashMap<String, Object>();
		map.put("map_show_item", getString(R.string.local));
		adapt.add(map);

		map = new HashMap<String, Object>();
		map.put("map_show_item", getString(R.string.local_detail));
		adapt.add(map);

		SimpleAdapter listAdapter = new SimpleAdapter(this, adapt, R.layout.listview_item,
				new String[] { "map_show_item" }, new int[] { R.id.tv });
		listView.setAdapter(listAdapter);
		listView.setOnItemClickListener(new ListViewItemClickListener());

	}

	private class ListViewItemClickListener implements OnItemClickListener {

		@Override
		public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
			switch (position) {
			case 0: // 地图显示 平移 缩放Demo
			case 1:
			case 2:
				startMapViewDemo();
				break;
			case 3: // 标注地图Demo
				startItemizedOverlayDemo();
				break;
			case 4: // 画线Demo
				startDrawLineOverlayDemo();
				break;
			case 5: // 绘制多边形Demo
				startDrawPolygonOverlayDemo();
				break;
			case 6: // 画圈Demo
				startDrawCircleOverlayDemo();
				break;
			case 7: // Intent方式
				startIntentPoiDemo();
				break;
			}
		}
	}


	private void startMapViewDemo() {
		Intent intent = null;
		intent = new Intent(MapbarDemo.this, MapViewDemo.class);

		this.startActivity(intent);
	}

	private void startItemizedOverlayDemo() {
		Intent intent = null;
		intent = new Intent(MapbarDemo.this, ItemizedOverlayDemo.class);

		this.startActivity(intent);
	}

	private void startDrawLineOverlayDemo() {
		Intent intent = null;
		intent = new Intent(MapbarDemo.this, DrawLineDemo.class);

		this.startActivity(intent);
	}

	private void startDrawPolygonOverlayDemo() {
		Intent intent = null;
		intent = new Intent(MapbarDemo.this, DrawPolygonDemo.class);

		this.startActivity(intent);
	}

	private void startDrawCircleOverlayDemo() {
		Intent intent = null;
		intent = new Intent(MapbarDemo.this, DrawCircleDemo.class);
		this.startActivity(intent);
	}

	private void startIntentPoiDemo() {
		try {
			// 直接调用图吧地图
			Intent intent = new Intent(Intent.ACTION_VIEW);
			Uri uri = Uri.parse("geo:39.922840,116.3543240,北京市西城区阜外大街2号万通大厦");
			intent.setData(uri);
			intent.setClassName("com.mapbar.android.mapbarmap", "com.mapbar.android.mapbarmap.OutCallMapViewActivity");
			this.startActivity(intent);
		} catch (Exception ex) {
			// 使用图吧地图引擎开发
			Intent intent = new Intent();
			intent.putExtra("lat", "39.922840");
			intent.putExtra("lon", "116.3543240");
			intent.putExtra("address", "北京市西城区阜外大街2号万通大厦");
			intent.setClass(MapbarDemo.this, IntentOverlayDemo.class);
			this.startActivity(intent);
		}
	}
}